@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito;
 {
-  $Mojito::VERSION = '0.20';
+  $Mojito::VERSION = '0.21';
 }
 use Moo;
 use Path::Class;
@@ -75,6 +75,9 @@ sub create_page {
     $page_struct->{page_html} = $self->render_page($page_struct);
     $page_struct->{body_html} = $self->render_body($page_struct);
     $page_struct->{title}     = $self->intro_text( $page_struct->{body_html} );
+    if ($params->{public}) {
+        $page_struct->{public} = 1;
+    }
     my $id = $self->create($page_struct);
     $params->{id} = $id;
     # Put into repo
@@ -147,6 +150,9 @@ sub update_page {
         # A document that is part of a feed is considered public by default
         $page->{public} = 1;
     }
+    if ($params->{public}) {
+        $page->{public} = 1;
+    }
     my $collection_ids = $params->{collection_select};
     # Want to coerce (single select) SCALAR into an ArrayRef (happens w/ Dancer params)
     if (ref($collection_ids) ne 'ARRAY') {
