@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Filter::Shortcuts;
 {
-  $Mojito::Filter::Shortcuts::VERSION = '0.20';
+  $Mojito::Filter::Shortcuts::VERSION = '0.21';
 }
 use Moo::Role;
 use MooX::Types::MooseLike::Base qw(:all);
@@ -19,7 +19,14 @@ has shortcuts => (
 );
 sub _build_shortcuts {
     my $self = shift;
-    my @shortcuts = qw( cpan_URL metacpan_module_URL metacpan_author_URL internal_URL cpan_recent_synopses cpan_synopsis);
+    my @shortcuts = qw( 
+        cpan_URL
+        metacpan_module_URL
+        metacpan_author_URL
+        internal_URL
+        gist_URL
+        cpan_recent_synopses
+        cpan_synopsis);
     push @shortcuts, 'fonality_ticket' if ($self->config->{fonality_ticket_url});
     return \@shortcuts;
 }
@@ -49,7 +56,20 @@ Expand the cpan abbreviated shortcut.
 sub cpan_URL {
     my ($self, $content) = @_;
     return if !$content;
-    $content =~ s/{{cpan\s+([^}]*)}}/<a href="http:\/\/search.cpan.org\/perldoc?$1">$1<\/a>/sig;
+    $content =~ s/\{\{cpan\s+([^}]*)}}/<a href="http:\/\/search.cpan.org\/perldoc?$1">$1<\/a>/sig;
+    return $content;
+}
+
+=head2 gist_URL
+
+Expand the gist.github.com abbreviated shortcut.
+
+=cut
+
+sub gist_URL {
+    my ($self, $content) = @_;
+    return if !$content;
+    $content =~ s/\{\{gist\s+([^}]*)}}/<script src="https:\/\/gist.github.com\/$1.js"><\/script>/sig;
     return $content;
 }
 
@@ -68,7 +88,7 @@ Show the CPAN SYNOPSIS for a Perl Module
 sub cpan_synopsis {
     my ($self, $content) = @_;
     return if !$content;
-    $content =~ s/{{cpan.synopsis\s+([^}]*)}}/$self->metacpan->get_synopsis_formatted($1, 'presentation')/esig;
+    $content =~ s/\{\{cpan.synopsis\s+([^}]*)}}/$self->metacpan->get_synopsis_formatted($1, 'presentation')/esig;
     return $content;
 }
 
@@ -81,7 +101,7 @@ Show the synopses of the CPAN recent releases
 sub cpan_recent_synopses {
     my ($self, $content) = @_;
     return if !$content;
-    $content =~ s/{{cpan.synopses.recent\s*(\d+)}}/$self->metacpan->get_recent_synopses($1)/esig;
+    $content =~ s/\{\{cpan.synopses.recent\s*(\d+)}}/$self->metacpan->get_recent_synopses($1)/esig;
     return $content;
 }
 =head2 metacpan_module_URL
@@ -93,7 +113,7 @@ Expand the cpan abbreviated shortcut.
 sub metacpan_module_URL {
     my ($self, $content) = @_;
     return if !$content;
-    $content =~ s|{{metacpan\s+([^}]*)}}|<a href="http://metacpan.org/module/$1">$1</a>|sig;
+    $content =~ s|\{\{metacpan\s+([^}]*)}}|<a href="http://metacpan.org/module/$1">$1</a>|sig;
     return $content;
 }
 =head2 metacpan_module_URL
@@ -105,7 +125,7 @@ Expand the cpan abbreviated shortcut.
 sub metacpan_author_URL {
     my ($self, $content) = @_;
     return if !$content;
-    $content =~ s|{{metacpan.author\s+([^}]*)}}|<a href="http://metacpan.org/author/$1">$1</a>|sig;
+    $content =~ s|\{\{metacpan.author\s+([^}]*)}}|<a href="http://metacpan.org/author/$1">$1</a>|sig;
     return $content;
 }
 
@@ -140,18 +160,4 @@ sub internal_URL {
     return $content;
 }
 
-=head2 fonality_ticket
-
-Expand the fonality ticket abbreviated shortcut.
-
-=cut
-
-sub fonality_ticket {
-    my ($self, $content) = @_;
-    return if !($content && $self->config->{fonality_ticket_url});
-    my $url = $self->config->{fonality_ticket_url};
-    $content =~ s/{{fontic\s+(\d+)[^}]*}}/<a href="${url}${1}">${1}<\/a>/sig;
-    return $content;
-}
-
-1
+1
\ No newline at end of file
